==> Gambio v4.1.1.2.zip: Vollversion GX v4.1.1.2/Shopsystem/Dateien/lang/german/original_sections/admin/currencies.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	currencies.lang.inc.php 2015-01-02 gm
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'ERROR_CURRENCY_INVALID' => 'Fehler: Der Wechselkurs für %s (%s) wurde nicht aktualisiert. Ist dies ein gültiges Währungskürzel?',
	'ERROR_REMOVE_DEFAULT_CURRENCY' => 'Hinweis: Die Standardwährung darf nicht gelöscht werden. Bitte definieren Sie eine neue Standardwährung um diese Währung löschen zu können.',
	'HEADING_SUB_TITLE' => 'Länder / Steuern',
	'HEADING_TITLE' => 'Währungen',
	'TABLE_HEADING_ACTION' => 'Aktion',
	'TABLE_HEADING_CURRENCY_CODES' => 'Kürzel',
	'TABLE_HEADING_CURRENCY_NAME' => 'Währung',
	'TABLE_HEADING_CURRENCY_VALUE' => 'Wert',
	'TEXT_INFO_CURRENCY_CODE' => 'Kürzel:',
	'TEXT_INFO_CURRENCY_DECIMAL_PLACES' => 'Dezimalstellen:',
	'TEXT_INFO_CURRENCY_DECIMAL_POINT' => 'Dezimaltrennzeichen:',
	'TEXT_INFO_CURRENCY_EXAMPLE' => 'Beispiel:',
	'TEXT_INFO_CURRENCY_LAST_UPDATED' => 'letzte Änderung:',
	'TEXT_INFO_CURRENCY_SYMBOL_LEFT' => 'Symbol links:',
	'TEXT_INFO_CURRENCY_SYMBOL_RIGHT' => 'Symbol rechts:',
	'TEXT_INFO_CURRENCY_THOUSANDS_POINT' => 'Tausendertrennzeichen:',
	'TEXT_INFO_CURRENCY_TITLE' => 'Name:',
	'TEXT_INFO_CURRENCY_UPDATED' => 'Der Wechselkurs %s (%s) wurde erfolgreich aktualisiert.',
	'TEXT_INFO_CURRENCY_VALUE' => 'Wert (bei Standardwährung 1.00000000):',
	'TEXT_INFO_DELETE_INTRO' => 'Sind Sie sicher, dass Sie diese Währung löschen möchten?',
	'TEXT_INFO_EDIT_INTRO' => 'Bitte führen Sie alle notwendigen Änderungen durch.',
	'TEXT_INFO_HEADING_DELETE_CURRENCY' => 'Währung löschen',
	'TEXT_INFO_HEADING_EDIT_CURRENCY' => 'Währung bearbeiten',
	'TEXT_INFO_HEADING_NEW_CURRENCY' => 'neue Währung',
	'TEXT_INFO_INSERT_INTRO' => 'Bitte geben Sie die neue Währung mit allen relevanten Daten ein.',
	'TEXT_INFO_SET_AS_DEFAULT' => ' (manuelles Aktualisieren der Wechselkurse erforderlich.)',
	'BUTTON_UPDATE_EXCHANGE_RATES' => 'Wechselkurse aktualisieren'
);

==> Gambio v4.5.2.2.zip: Vollversion GX v4.5.2.2/Shopsystem/Dateien/lang/german/original_sections/admin/currencies.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	currencies.lang.inc.php 2015-01-02 gm
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'ERROR_CURRENCY_INVALID' => 'Fehler: Der Wechselkurs für %s (%s) wurde nicht aktualisiert. Ist dies ein gültiges Währungskürzel?',
	'ERROR_REMOVE_DEFAULT_CURRENCY' => 'Hinweis: Die Standardwährung darf nicht gelöscht werden. Bitte lege eine neue Standardwährung fest, um diese Währung löschen zu können.',
	'HEADING_SUB_TITLE' => 'Länder / Steuern',
	'HEADING_TITLE' => 'Währungen',
	'TABLE_HEADING_ACTION' => 'Aktion',
	'TABLE_HEADING_CURRENCY_CODES' => 'Kürzel',
	'TABLE_HEADING_CURRENCY_NAME' => 'Währung',
	'TABLE_HEADING_CURRENCY_VALUE' => 'Wert',
	'TEXT_INFO_CURRENCY_CODE' => 'Kürzel:',
	'TEXT_INFO_CURRENCY_DECIMAL_PLACES' => 'Dezimalstellen:',
	'TEXT_INFO_CURRENCY_DECIMAL_POINT' => 'Dezimaltrennzeichen:',
	'TEXT_INFO_CURRENCY_EXAMPLE' => 'Beispiel:',
	'TEXT_INFO_CURRENCY_LAST_UPDATED' => 'letzte Änderung:',
	'TEXT_INFO_CURRENCY_SYMBOL_LEFT' => 'Symbol links:',
	'TEXT_INFO_CURRENCY_SYMBOL_RIGHT' => 'Symbol rechts:',
	'TEXT_INFO_CURRENCY_THOUSANDS_POINT' => 'Tausendertrennzeichen:',
	'TEXT_INFO_CURRENCY_TITLE' => 'Name:',
	'TEXT_INFO_CURRENCY_UPDATED' => 'Der Wechselkurs %s (%s) wurde erfolgreich aktualisiert.',
	'TEXT_INFO_CURRENCY_VALUE' => 'Wert (bei Standardwährung 1.00000000):',
	'TEXT_INFO_DELETE_INTRO' => 'Bist du sicher, dass du diese Währung löschen möchtest?',
	'TEXT_INFO_EDIT_INTRO' => 'Bitte führe alle notwendigen Änderungen durch.',
	'TEXT_INFO_HEADING_DELETE_CURRENCY' => 'Währung löschen',
	'TEXT_INFO_HEADING_EDIT_CURRENCY' => 'Währung bearbeiten',
	'TEXT_INFO_HEADING_NEW_CURRENCY' => 'Neue Währung',
	'TEXT_INFO_INSERT_INTRO' => 'Bitte gib die neue Währung mit allen relevanten Daten ein.',
	'TEXT_INFO_SET_AS_DEFAULT' => ' (manuelles Aktualisieren der Wechselkurse erforderlich.)',
	'BUTTON_UPDATE_EXCHANGE_RATES' => 'Wechselkurse aktualisieren'
);
